@@ -5,40 +5,59 @@ set.seed(123)
 test.data <- exposure.response.sample.with.cov
 test.data.short <- sample_n(test.data, 30)
 
-
-test.fit <- stan_emax(resp ~ conc,
+test.fit <- stan_emax(
+  formula = resp ~ conc,
   data = test.data,
-  chains = 2, iter = 1000, refresh = 0
+  chains = 2,
+  iter = 1000,
+  refresh = 0
 )
 
 test.fit.2cov <- stan_emax(
-  formula = resp ~ conc, data = test.data,
+  formula = resp ~ conc,
+  data = test.data,
   param.cov = list(emax = "cov2", ec50 = "cov3"),
-  chains = 2, iter = 1000, refresh = 0
+  chains = 2,
+  iter = 1000,
+  refresh = 0
 )
 
 context("test-posterior_predict")
 
 test_that("returnType specification", {
   expect_error(
-    posterior_predict.stanemax(test.fit, returnType = "tabble"),
+    suppressWarnings(posterior_predict(test.fit, returnType = "tabble")),
     "'arg' should be one of*"
   )
 })
 
 
 test_that("posterior prediction with original data", {
-  test.pp.matrix <- posterior_predict.stanemax(test.fit)
-  test.pp.df <- posterior_predict.stanemax(test.fit, returnType = "dataframe")
+  test.pp.matrix <- posterior_predict(test.fit)
+  test.pe.matrix <- posterior_epred(test.fit)
+  test.pl.matrix <- posterior_linpred(test.fit)
+
+  test.pp.df <- posterior_predict(test.fit, returnType = "dataframe")
 
   expect_is(test.pp.matrix, "matrix")
+  expect_is(test.pe.matrix, "matrix")
+  expect_is(test.pl.matrix, "matrix")
+
   expect_is(test.pp.df, "data.frame")
 
   expect_equal(dim(test.pp.matrix), c(1000, 60))
+  expect_equal(dim(test.pe.matrix), c(1000, 60))
+  expect_equal(dim(test.pl.matrix), c(1000, 60))
+
   expect_equal(nrow(test.pp.df), 60000)
 
   expect_equal(mean(test.pp.matrix[, 1]), 15, tolerance = 2, scale = 1)
+  expect_equal(mean(test.pl.matrix[, 1]), 15.2, tolerance = 1, scale = 1) # expect higher tolerance for expectations
+  expect_equal(mean(test.pe.matrix[, 1]), 15.2, tolerance = 1, scale = 1)
+
   expect_equal(mean(test.pp.matrix[, 30]), 83, tolerance = 15, scale = 1)
+  expect_equal(mean(test.pl.matrix[, 30]), 70, tolerance = 5, scale = 1)
+  expect_equal(mean(test.pe.matrix[, 30]), 70, tolerance = 5, scale = 1)
 })
 
 
@@ -65,6 +84,15 @@ test_that("posterior prediction with new data with covariates", {
     posterior_predict.stanemax(test.fit.2cov, newdata = newdata.vec),
     "Covariate specified with `param.cov` does not exist in the dataset"
   )
+  expect_error(
+    posterior_epred.stanemax(test.fit.2cov, newdata = newdata.vec),
+    "Covariate specified with `param.cov` does not exist in the dataset"
+  )
+  expect_error(
+    posterior_linpred.stanemax(test.fit.2cov, newdata = newdata.vec),
+    "Covariate specified with `param.cov` does not exist in the dataset"
+  )
+
 
   # Make sure parameter extraction works fine
   param.fit.with2cov <- extract_param_fit(test.fit.2cov$stanfit)
